diff options
| author | Vedant Kumar <vsk@apple.com> | 2020-02-17 13:53:59 -0800 |
|---|---|---|
| committer | Vedant Kumar <vsk@apple.com> | 2020-02-17 14:04:22 -0800 |
| commit | 3f148eabe0977228410090951cdb236d881eebcd (patch) | |
| tree | b43e8a1e5b3c1bcca79e4940562d324f2cf18501 /lldb/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp | |
| parent | 0deef2e164e1db5e262fb14906c97b01b74a24dd (diff) | |
[LiveDebugValues] Visit open var locs just once in transferRegisterDef, NFC
For a file in WebKit, this brings the time spent in LiveDebugValues down
from 16 minutes to 2 minutes. The reduction comes from iterating the set
of open variable locations just once in transferRegisterDef. Post-patch,
the most expensive item inside of transferRegisterDef is a call to
VarLoc::isDescribedByReg, which we have to do.
Testing: I built LNT using the Os-g cmake cache with & without this
patch, then diffed the object files to verify there was no binary diff.
rdar://59446577
Differential Revision: https://reviews.llvm.org/D74633
Diffstat (limited to 'lldb/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp')
0 files changed, 0 insertions, 0 deletions
